@@ -255,7 +255,7 @@ class AnalyzeSwaggerClientWrapper:
         return check_exists(get_data_set.sync(client=self._client, id=data_set_id))
 
     def edit_data_set(
-        self, data_set_id: int, name: str, description: str = None
+        self, data_set_id: int, name: str, description: Optional[str] = None
     ) -> dto.DataSetResponse:
         payload = dto.EditDataSetRequest(name=name, description=description)
         return check_exists(
@@ -525,7 +525,6 @@ class AnalyzeSwaggerClientWrapper:
         excluded_columns: Optional[List[str]] = None,
         wait_until_complete: bool = True,
     ) -> int:
-
         payload = dto.CreateClusteringRequest(
             name=name,
             data_set_id=data_set_id,
@@ -780,7 +779,7 @@ class AnalyzeSwaggerClientWrapper:
         model_id: int,
         data_set_id: int,
         name: str,
-        description: str = None,
+        description: Optional[str] = None,
         wait_until_complete: bool = True,
     ) -> int:
         prediction_id = check_exists(
@@ -800,7 +799,7 @@ class AnalyzeSwaggerClientWrapper:
         return wait_for_prediction_to_complete(self._client, prediction_id)
 
     def edit_prediction(
-        self, prediction_id: int, name: str, description: str = None
+        self, prediction_id: int, name: str, description: Optional[str] = None
     ) -> dto.PredictionResponse:
         payload = dto.EditPredictionRequest(name=name, description=description)
         return check_exists(
@@ -891,7 +890,7 @@ class AnalyzeSwaggerClientWrapper:
         model_id: int,
         data_set_id: int,
         name: str,
-        description: str = None,
+        description: Optional[str] = None,
         wait_until_complete: bool = True,
     ) -> int:
         test_id = check_exists(
@@ -911,7 +910,7 @@ class AnalyzeSwaggerClientWrapper:
         return wait_for_test_to_complete(self._client, test_id)
 
     def edit_test(
-        self, test_id: int, name: str, description: str = None
+        self, test_id: int, name: str, description: Optional[str] = None
     ) -> dto.TestResponse:
         payload = dto.EditTestRequest(name=name, description=description)
         return check_exists(
