@@ -1,5 +1,6 @@
 # Re-export these so they can be accessed from this package
 from mindfoundry.client.analyze.swagger.models import (
+    ClassificationModelType,
     ClassificationScorers,
     CreateAutoClusteringRequest,
     CreateClassificationRequest,
@@ -16,8 +17,10 @@ from mindfoundry.client.analyze.swagger.models import (
     ModelValidationMethod,
     NlpLanguage,
     ProblemType,
+    RegressionModelType,
     RegressionScorers,
     ScoreType,
+    TargetDistributions,
 )
 
 from .classifier import AnalyzeClassifier
