@@ -128,6 +128,7 @@ class AnalyzeClassifier(AnalyzeModel):
         wait_until_complete: bool = True,
         # Classification specific fit parameters
         sample_weight: Optional[str] = None,
+        hold_out_percentage: Optional[float] = 10.0,
     ) -> "AnalyzeClassifier":
         """Fit the classification model using random data partitioning"""
 
@@ -142,6 +143,7 @@ class AnalyzeClassifier(AnalyzeModel):
         # Classification specific fit parameters
         sample_weight: Optional[str] = None,
         order_by: str,
+        hold_out_percentage: Optional[float] = 10.0,
     ) -> "AnalyzeClassifier":
         """Fit the classification model using ordered data partitioning"""
 
@@ -156,6 +158,7 @@ class AnalyzeClassifier(AnalyzeModel):
         # Classification specific fit parameters
         partition_by: str,
         sample_weight: Optional[str] = None,
+        hold_out_percentage=None,
     ) -> "AnalyzeClassifier":
         """Fit the classification model using manual data partitioning"""
 
@@ -170,6 +173,7 @@ class AnalyzeClassifier(AnalyzeModel):
         # Classification specific fit parameters
         sample_weight: Optional[str] = None,
         no_mixing: List[str],
+        hold_out_percentage: Optional[float] = 10.0,
     ) -> "AnalyzeClassifier":
         """Fit the classification model using a no-mixing column data partitioning"""
 
@@ -184,6 +188,7 @@ class AnalyzeClassifier(AnalyzeModel):
         sample_weight: Optional[str] = None,
         order_by: Optional[str] = None,
         partition_by: Optional[str] = None,
+        hold_out_percentage: Optional[float] = 10.0,
         no_mixing: Optional[List[str]] = None,
     ) -> "AnalyzeClassifier":
         """Internal method - DO NOT USE"""
@@ -196,5 +201,6 @@ class AnalyzeClassifier(AnalyzeModel):
             partition_by=partition_by,
             no_mixing=no_mixing,
             sample_weight=sample_weight,
+            hold_out_percentage=hold_out_percentage,
         )
         return self
