@@ -7,6 +7,7 @@ from ....swagger.models import (
     ProblemType,
     RegressionModelType,
     RegressionScorers,
+    TargetDistributions,
 )
 from ....utils.typing import UNSET, PathLike, Unset
 from ...connection import ConnectionLike, from_connectionlike
@@ -31,6 +32,10 @@ class AnalyzeRegressor(AnalyzeModel):
         number_of_evaluations: int = 300,
         nlp_language: NlpLanguage = NlpLanguage.AUTO_DETECT,
         draft_mode: bool = False,
+        model_types: Optional[List[RegressionModelType]] = None,
+        target_distribution: Optional[
+            TargetDistributions
+        ] = TargetDistributions.GAUSSIAN,
         *,
         connection: ConnectionLike,
     ):
@@ -45,12 +50,10 @@ class AnalyzeRegressor(AnalyzeModel):
         :param draft_mode: Create a draft model rather than a fully optimized model
         :param connection: The connection to the Analyze project in which the model will be created
         """
-        ...
 
     @overload
     def __init__(self, *, _internal_model: BaseModel):
         """Internal constructor - DO NOT USE"""
-        ...
 
     def __init__(
         self,
@@ -62,6 +65,9 @@ class AnalyzeRegressor(AnalyzeModel):
         nlp_language: NlpLanguage = NlpLanguage.AUTO_DETECT,
         draft_mode: bool = False,
         model_types: Optional[List[RegressionModelType]] = None,
+        target_distribution: Optional[
+            TargetDistributions
+        ] = TargetDistributions.GAUSSIAN,
         *,
         connection: Union[ConnectionLike, Unset] = UNSET,
         _internal_model: Union[BaseModel, Unset] = UNSET,
@@ -85,6 +91,7 @@ class AnalyzeRegressor(AnalyzeModel):
                 nlp_language=nlp_language,
                 draft_mode=draft_mode,
                 model_types=model_types,
+                target_distribution=target_distribution,
             )
             super().__init__(_internal_model=LocalRegressor(connection, initial_config))
 
@@ -129,9 +136,9 @@ class AnalyzeRegressor(AnalyzeModel):
         wait_until_complete: bool = True,
         # Regression specific fit parameters
         sample_weight: Optional[str] = None,
+        hold_out_percentage: Optional[float] = 10.0,
     ) -> "AnalyzeRegressor":
         """Fit the regression model using random data partitioning"""
-        ...
 
     @overload
     def fit(
@@ -144,9 +151,9 @@ class AnalyzeRegressor(AnalyzeModel):
         # Regression specific fit parameters
         sample_weight: Optional[str] = None,
         order_by: str,
+        hold_out_percentage: Optional[float] = 10.0,
     ) -> "AnalyzeRegressor":
         """Fit the regression model using ordered data partitioning"""
-        ...
 
     @overload
     def fit(
@@ -159,9 +166,9 @@ class AnalyzeRegressor(AnalyzeModel):
         # Regression specific fit parameters
         sample_weight: Optional[str] = None,
         partition_by: str,
+        hold_out_percentage=None,
     ) -> "AnalyzeRegressor":
         """Fit the regression model using manual data partitioning"""
-        ...
 
     @overload
     def fit(
@@ -174,9 +181,9 @@ class AnalyzeRegressor(AnalyzeModel):
         # Regression specific fit parameters
         sample_weight: Optional[str] = None,
         no_mixing: List[str],
+        hold_out_percentage: Optional[float] = 10.0,
     ) -> "AnalyzeRegressor":
         """Fit the regression model using a no-mixing column data partitioning"""
-        ...
 
     def fit(
         self,
@@ -190,6 +197,7 @@ class AnalyzeRegressor(AnalyzeModel):
         order_by: Optional[str] = None,
         partition_by: Optional[str] = None,
         no_mixing: Optional[List[str]] = None,
+        hold_out_percentage: Optional[float] = 10.0,
     ) -> "AnalyzeRegressor":
         """Internal method - DO NOT USE"""
         # Fit must explicitly override the model with the new fitted model
@@ -202,5 +210,6 @@ class AnalyzeRegressor(AnalyzeModel):
             partition_by=partition_by,
             no_mixing=no_mixing,
             sample_weight=sample_weight,
+            hold_out_percentage=hold_out_percentage,
         )
         return self
