@@ -13,6 +13,7 @@ def _get_kwargs(
     separator: Union[Unset, None, str] = UNSET,
     quote_char: Union[Unset, None, str] = UNSET,
     escape_char: Union[Unset, None, str] = UNSET,
+    charset: Union[Unset, None, str] = 'UTF-8',
 
 ) -> Dict[str, Any]:
     url = "{}/v1/models/{id}/results/csv".format(
@@ -35,6 +36,9 @@ def _get_kwargs(
     params["escapeChar"] = escape_char
 
 
+    params["charset"] = charset
+
+
 
     params = {k: v for k, v in params.items() if v is not UNSET and v is not None}
 
@@ -71,6 +75,7 @@ def sync_detailed(
     separator: Union[Unset, None, str] = UNSET,
     quote_char: Union[Unset, None, str] = UNSET,
     escape_char: Union[Unset, None, str] = UNSET,
+    charset: Union[Unset, None, str] = 'UTF-8',
 
 ) -> Response[Any]:
     """Get the model result in CSV format
@@ -83,6 +88,7 @@ def sync_detailed(
         separator (Union[Unset, None, str]):
         quote_char (Union[Unset, None, str]):
         escape_char (Union[Unset, None, str]):
+        charset (Union[Unset, None, str]):  Default: 'UTF-8'.
 
     Returns:
         Response[Any]
@@ -95,6 +101,7 @@ client=client,
 separator=separator,
 quote_char=quote_char,
 escape_char=escape_char,
+charset=charset,
 
     )
 
@@ -113,6 +120,7 @@ async def asyncio_detailed(
     separator: Union[Unset, None, str] = UNSET,
     quote_char: Union[Unset, None, str] = UNSET,
     escape_char: Union[Unset, None, str] = UNSET,
+    charset: Union[Unset, None, str] = 'UTF-8',
 
 ) -> Response[Any]:
     """Get the model result in CSV format
@@ -125,6 +133,7 @@ async def asyncio_detailed(
         separator (Union[Unset, None, str]):
         quote_char (Union[Unset, None, str]):
         escape_char (Union[Unset, None, str]):
+        charset (Union[Unset, None, str]):  Default: 'UTF-8'.
 
     Returns:
         Response[Any]
@@ -137,6 +146,7 @@ client=client,
 separator=separator,
 quote_char=quote_char,
 escape_char=escape_char,
+charset=charset,
 
     )
 
