@@ -26,6 +26,7 @@ class CreateClassificationRequest:
         excluded_columns (Union[Unset, List[str]]):
         nlp_language (Union[Unset, NlpLanguage]):  Default: NlpLanguage.AUTO_DETECT.
         draft_mode (Union[Unset, bool]):
+        hold_out_percentage (Union[Unset, float]):  Default: 10.0.
         no_mixing_columns (Union[Unset, List[str]]):
         partition_column (Union[Unset, str]):
         order_by_column (Union[Unset, str]):
@@ -44,6 +45,7 @@ class CreateClassificationRequest:
     excluded_columns: Union[Unset, List[str]] = UNSET
     nlp_language: Union[Unset, NlpLanguage] = NlpLanguage.AUTO_DETECT
     draft_mode: Union[Unset, bool] = UNSET
+    hold_out_percentage: Union[Unset, float] = 10.0
     no_mixing_columns: Union[Unset, List[str]] = UNSET
     partition_column: Union[Unset, str] = UNSET
     order_by_column: Union[Unset, str] = UNSET
@@ -76,6 +78,7 @@ class CreateClassificationRequest:
             nlp_language = self.nlp_language.value
 
         draft_mode = self.draft_mode
+        hold_out_percentage = self.hold_out_percentage
         no_mixing_columns: Union[Unset, List[str]] = UNSET
         if not isinstance(self.no_mixing_columns, Unset):
             no_mixing_columns = self.no_mixing_columns
@@ -117,6 +120,8 @@ class CreateClassificationRequest:
             field_dict["nlpLanguage"] = nlp_language
         if draft_mode is not UNSET:
             field_dict["draftMode"] = draft_mode
+        if hold_out_percentage is not UNSET:
+            field_dict["holdOutPercentage"] = hold_out_percentage
         if no_mixing_columns is not UNSET:
             field_dict["noMixingColumns"] = no_mixing_columns
         if partition_column is not UNSET:
@@ -175,6 +180,8 @@ class CreateClassificationRequest:
 
         draft_mode = d.pop("draftMode", UNSET)
 
+        hold_out_percentage = d.pop("holdOutPercentage", UNSET)
+
         no_mixing_columns = cast(List[str], d.pop("noMixingColumns", UNSET))
 
 
@@ -206,6 +213,7 @@ class CreateClassificationRequest:
             excluded_columns=excluded_columns,
             nlp_language=nlp_language,
             draft_mode=draft_mode,
+            hold_out_percentage=hold_out_percentage,
             no_mixing_columns=no_mixing_columns,
             partition_column=partition_column,
             order_by_column=order_by_column,
