@@ -4,7 +4,7 @@ from enum import Enum
 class CreateDbDataSetRequestDbType(str, Enum):
     POSTGRESQL = "postgresql"
     MYSQL = "mysql"
-    D_B2 = "db2"
+    DB2 = "db2"
     SQLSERVER = "sqlserver"
 
     def __str__(self) -> str:
