@@ -14,7 +14,8 @@ class CreateFileDataSetRequest:
         name (str):
         data (File):
         description (Union[Unset, str]):
-        parse_options (Union[Unset, str]):
+        parse_options (Union[Unset, str]): This parameter is a string for multipart-form compatibility. If provided it
+            should be string of JSON matching the appropriate ParseOptions (CSV or Parquet) schema
     """
 
     name: str
