@@ -6,13 +6,17 @@ T = TypeVar("T", bound="CreateModelResponse")
 
 @attr.s(auto_attribs=True)
 class CreateModelResponse:
-    """  """
+    """
+    Attributes:
+        id (int):
+    """
+
     id: int
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
 
     def to_dict(self) -> Dict[str, Any]:
-        id =  self.id
+        id = self.id
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -22,6 +26,8 @@ class CreateModelResponse:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
