@@ -12,7 +12,6 @@ class CsvParseOptions:
     """
     Attributes:
         file_type (CsvParseOptionsFileType):
-        charset (str):  Default: 'UTF-8'.
         column_names_in_header (Union[Unset, bool]): The first row contains column names
         separator (Union[Unset, str]): The character to use to separate the different columns in the CSV file. Defaults
             to comma.
@@ -22,35 +21,35 @@ class CsvParseOptions:
             inside a quoted section. Defaults to backslash
         skip_top (Union[Unset, int]): Ignore the first n rows
         skip_bottom (Union[Unset, int]): Ignore the last n rows
+        charset (Union[Unset, str]):  Default: 'UTF-8'.
     """
 
     file_type: CsvParseOptionsFileType
-    charset: str = 'UTF-8'
     column_names_in_header: Union[Unset, bool] = False
     separator: Union[Unset, str] = UNSET
     quote_char: Union[Unset, str] = UNSET
     escape_char: Union[Unset, str] = UNSET
     skip_top: Union[Unset, int] = 0
     skip_bottom: Union[Unset, int] = 0
+    charset: Union[Unset, str] = 'UTF-8'
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
 
     def to_dict(self) -> Dict[str, Any]:
         file_type = self.file_type.value
 
-        charset = self.charset
         column_names_in_header = self.column_names_in_header
         separator = self.separator
         quote_char = self.quote_char
         escape_char = self.escape_char
         skip_top = self.skip_top
         skip_bottom = self.skip_bottom
+        charset = self.charset
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
         field_dict.update({
             "fileType": file_type,
-            "charset": charset,
         })
         if column_names_in_header is not UNSET:
             field_dict["columnNamesInHeader"] = column_names_in_header
@@ -64,6 +63,8 @@ class CsvParseOptions:
             field_dict["skipTop"] = skip_top
         if skip_bottom is not UNSET:
             field_dict["skipBottom"] = skip_bottom
+        if charset is not UNSET:
+            field_dict["charset"] = charset
 
         return field_dict
 
@@ -77,8 +78,6 @@ class CsvParseOptions:
 
 
 
-        charset = d.pop("charset")
-
         column_names_in_header = d.pop("columnNamesInHeader", UNSET)
 
         separator = d.pop("separator", UNSET)
@@ -91,15 +90,17 @@ class CsvParseOptions:
 
         skip_bottom = d.pop("skipBottom", UNSET)
 
+        charset = d.pop("charset", UNSET)
+
         csv_parse_options = cls(
             file_type=file_type,
-            charset=charset,
             column_names_in_header=column_names_in_header,
             separator=separator,
             quote_char=quote_char,
             escape_char=escape_char,
             skip_top=skip_top,
             skip_bottom=skip_bottom,
+            charset=charset,
         )
 
         csv_parse_options.additional_properties = d
