@@ -5,6 +5,7 @@ import attr
 from dateutil.parser import isoparse
 
 from ..models.data_prep_step_response import DataPrepStepResponse
+from ..models.data_set_column_metadata_response import DataSetColumnMetadataResponse
 from ..models.status import Status
 from ..types import UNSET, Unset
 
@@ -21,6 +22,7 @@ class DataSetResponse:
         columns (int):
         created_at (datetime.datetime):
         created_by (str):
+        column_metadata (List[DataSetColumnMetadataResponse]):
         data_prep_steps (List[DataPrepStepResponse]):
         status (Status):
         description (Union[Unset, None, str]):
@@ -33,6 +35,7 @@ class DataSetResponse:
     columns: int
     created_at: datetime.datetime
     created_by: str
+    column_metadata: List[DataSetColumnMetadataResponse]
     data_prep_steps: List[DataPrepStepResponse]
     status: Status
     description: Union[Unset, None, str] = UNSET
@@ -48,6 +51,15 @@ class DataSetResponse:
         created_at = self.created_at.isoformat()
 
         created_by = self.created_by
+        column_metadata = []
+        for column_metadata_item_data in self.column_metadata:
+            column_metadata_item = column_metadata_item_data.to_dict()
+
+            column_metadata.append(column_metadata_item)
+
+
+
+
         data_prep_steps = []
         for data_prep_steps_item_data in self.data_prep_steps:
             data_prep_steps_item = data_prep_steps_item_data.to_dict()
@@ -71,6 +83,7 @@ class DataSetResponse:
             "columns": columns,
             "createdAt": created_at,
             "createdBy": created_by,
+            "columnMetadata": column_metadata,
             "dataPrepSteps": data_prep_steps,
             "status": status,
         })
@@ -101,6 +114,16 @@ class DataSetResponse:
 
         created_by = d.pop("createdBy")
 
+        column_metadata = []
+        _column_metadata = d.pop("columnMetadata")
+        for column_metadata_item_data in (_column_metadata):
+            column_metadata_item = DataSetColumnMetadataResponse.from_dict(column_metadata_item_data)
+
+
+
+            column_metadata.append(column_metadata_item)
+
+
         data_prep_steps = []
         _data_prep_steps = d.pop("dataPrepSteps")
         for data_prep_steps_item_data in (_data_prep_steps):
@@ -126,6 +149,7 @@ class DataSetResponse:
             columns=columns,
             created_at=created_at,
             created_by=created_by,
+            column_metadata=column_metadata,
             data_prep_steps=data_prep_steps,
             status=status,
             description=description,
