@@ -6,15 +6,20 @@ T = TypeVar("T", bound="DecisioningThreshold")
 
 @attr.s(auto_attribs=True)
 class DecisioningThreshold:
-    """  """
+    """
+    Attributes:
+        upper (float):
+        lower (float):
+    """
+
     upper: float
     lower: float
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
 
     def to_dict(self) -> Dict[str, Any]:
-        upper =  self.upper
-        lower =  self.lower
+        upper = self.upper
+        lower = self.lower
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -25,6 +30,8 @@ class DecisioningThreshold:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
