@@ -8,7 +8,11 @@ T = TypeVar("T", bound="JsonParseOptions")
 
 @attr.s(auto_attribs=True)
 class JsonParseOptions:
-    """  """
+    """
+    Attributes:
+        file_type (JsonParseOptionsFileType):
+    """
+
     file_type: JsonParseOptionsFileType
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
@@ -25,6 +29,8 @@ class JsonParseOptions:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
