@@ -6,15 +6,20 @@ T = TypeVar("T", bound="ModelInfluence")
 
 @attr.s(auto_attribs=True)
 class ModelInfluence:
-    """  """
+    """
+    Attributes:
+        name (str):
+        value (float):
+    """
+
     name: str
     value: float
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
 
     def to_dict(self) -> Dict[str, Any]:
-        name =  self.name
-        value =  self.value
+        name = self.name
+        value = self.value
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -25,6 +30,8 @@ class ModelInfluence:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
