@@ -8,14 +8,19 @@ T = TypeVar("T", bound="ModelScore")
 
 @attr.s(auto_attribs=True)
 class ModelScore:
-    """  """
+    """
+    Attributes:
+        value (float):
+        type (ScoreType):
+    """
+
     value: float
     type: ScoreType
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
 
     def to_dict(self) -> Dict[str, Any]:
-        value =  self.value
+        value = self.value
         type = self.type.value
 
 
@@ -28,6 +33,8 @@ class ModelScore:
 
         return field_dict
 
+
+
     @classmethod
     def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
         d = src_dict.copy()
